@@ -2,7 +2,13 @@
 
 from pathlib import Path
 import time
-from typing import List, Union
+from typing import TYPE_CHECKING, List, Optional, Union
+
+from jupyter_cache.readers import NbReadError
+
+if TYPE_CHECKING:
+    from jupyter_cache.base import JupyterCacheAbstract
+    from jupyter_cache.cache.db import NbCacheRecord, NbProjectRecord
 
 
 def to_relative_paths(
@@ -23,13 +29,13 @@ def to_relative_paths(
     for path in paths:
         path = Path(path).absolute()
         if check_existence and not path.exists():
-            raise IOError(f"Path does not exist: {path}")
+            raise OSError(f"Path does not exist: {path}")
         if check_existence and not path.is_file():
-            raise IOError(f"Path is not a file: {path}")
+            raise OSError(f"Path is not a file: {path}")
         try:
             rel_path = path.relative_to(folder)
         except ValueError:
-            raise IOError(f"Path '{path}' is not in folder '{folder}''")
+            raise OSError(f"Path '{path}' is not in folder '{folder}''")
         rel_paths.append(rel_path)
     return rel_paths
 
@@ -64,7 +70,7 @@ class Timer:
         self.split()
 
 
-def shorten_path(file_path, length):
+def shorten_path(file_path: Union[str, Path], length: Optional[int]) -> Path:
     """Split the path into separate parts,
     select the last 'length' elements and join them again
     """
@@ -73,7 +79,9 @@ def shorten_path(file_path, length):
     return Path(*Path(file_path).parts[-length:])
 
 
-def tabulate_cache_records(records: list, hashkeys=False, path_length=None) -> str:
+def tabulate_cache_records(
+    records: List["NbCacheRecord"], hashkeys=False, path_length=None
+) -> str:
     """Tabulate cache records.
 
     :param records: list of ``NbCacheRecord``
@@ -91,22 +99,37 @@ def tabulate_cache_records(records: list, hashkeys=False, path_length=None) -> s
     )
 
 
-def tabulate_stage_records(records: list, path_length=None, cache=None) -> str:
+def tabulate_project_records(
+    records: List["NbProjectRecord"],
+    path_length: Optional[int] = None,
+    cache: Optional["JupyterCacheAbstract"] = None,
+    assets=False,
+) -> str:
     """Tabulate cache records.
 
-    :param records: list of ``NbStageRecord``
+    :param records: list of ``NbProjectRecord``
     :param path_length: truncate URI paths to x components
     :param cache: If the cache is given,
         we use it to add a column of matched cached pk (if available)
+    :param assets: Show the number of assets
     """
     import tabulate
 
     rows = []
-    for record in sorted(records, key=lambda r: r.created, reverse=True):
+    for record in records:
         cache_record = None
+        read_error = None
         if cache is not None:
-            cache_record = cache.get_cache_record_of_staged(record.uri)
+            try:
+                cache_record = cache.get_cached_project_nb(record.uri)
+            except NbReadError as exc:
+                read_error = f"{exc.__class__.__name__}: {exc}"
         rows.append(
-            record.format_dict(cache_record=cache_record, path_length=path_length)
+            record.format_dict(
+                cache_record=cache_record,
+                path_length=path_length,
+                assets=assets,
+                read_error=read_error,
+            )
         )
     return tabulate.tabulate(rows, headers="keys")
